# OpenapiClient::ReportsApi

All URIs are relative to *https://stage.api.mastercard.com/golden-service*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_spending**](ReportsApi.md#get_spending) | **GET** /spending-reports | Retrieves e-commerce spending for a particular location, sector and date range or single date
[**get_top_locations**](ReportsApi.md#get_top_locations) | **GET** /top-locations | Retrieves the top grossing locations for the specified date/sector/spending type
[**get_top_sectors**](ReportsApi.md#get_top_sectors) | **GET** /top-sectors | Retrieves the top grossing sectors for the specified date &amp; location



## get_spending

> SpendingReport get_spending(date, location, spending_type, opts)

Retrieves e-commerce spending for a particular location, sector and date range or single date

### Example

```ruby
# load the gem
require 'openapi_client'

api_instance = OpenapiClient::ReportsApi.new
date = Date.parse('29/02/2019') # Date | The date for the requested data
location = 'New York' # String | The location for which you wish to receive the top-sectors report.
spending_type = 'ATV' # String | Used to distinguish between gross spending (GS) & average transaction value (ATV)
opts = {
  sector: 0 # Integer | The sector for which you wish to receive reports. Sector ids can be retrieved from sectors call
}

begin
  #Retrieves e-commerce spending for a particular location, sector and date range or single date
  result = api_instance.get_spending(date, location, spending_type, opts)
  p result
rescue OpenapiClient::ApiError => e
  puts "Exception when calling ReportsApi->get_spending: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **date** | **Date**| The date for the requested data | 
 **location** | **String**| The location for which you wish to receive the top-sectors report. | 
 **spending_type** | **String**| Used to distinguish between gross spending (GS) &amp; average transaction value (ATV) | 
 **sector** | **Integer**| The sector for which you wish to receive reports. Sector ids can be retrieved from sectors call | [optional] 

### Return type

[**SpendingReport**](SpendingReport.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_top_locations

> TopLocationsReport get_top_locations(date, spending_type, opts)

Retrieves the top grossing locations for the specified date/sector/spending type

### Example

```ruby
# load the gem
require 'openapi_client'

api_instance = OpenapiClient::ReportsApi.new
date = Date.parse('29/02/2019') # Date | The date for the requested data
spending_type = 'ATV' # String | Used to distinguish between gross spending (GS) & average transaction value (ATV)
opts = {
  sector: 0, # Integer | The sector for which you wish to receive reports. Sector ids can be retrieved from sectors call
  limit: 5, # Integer | Can be used to limit the amount of results returned from a query (Pagination)
  offset: 5 # Integer | The number of items to offset the start of the list from (Pagination)
}

begin
  #Retrieves the top grossing locations for the specified date/sector/spending type
  result = api_instance.get_top_locations(date, spending_type, opts)
  p result
rescue OpenapiClient::ApiError => e
  puts "Exception when calling ReportsApi->get_top_locations: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **date** | **Date**| The date for the requested data | 
 **spending_type** | **String**| Used to distinguish between gross spending (GS) &amp; average transaction value (ATV) | 
 **sector** | **Integer**| The sector for which you wish to receive reports. Sector ids can be retrieved from sectors call | [optional] 
 **limit** | **Integer**| Can be used to limit the amount of results returned from a query (Pagination) | [optional] 
 **offset** | **Integer**| The number of items to offset the start of the list from (Pagination) | [optional] 

### Return type

[**TopLocationsReport**](TopLocationsReport.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_top_sectors

> Array&lt;Array&gt; get_top_sectors(date, location, spending_type)

Retrieves the top grossing sectors for the specified date & location

### Example

```ruby
# load the gem
require 'openapi_client'

api_instance = OpenapiClient::ReportsApi.new
date = Date.parse('29/02/2019') # Date | The date for the requested data
location = 'New York' # String | The location for which you wish to receive the top-sectors report.
spending_type = 'ATV' # String | Used to distinguish between gross spending (GS) & average transaction value (ATV)

begin
  #Retrieves the top grossing sectors for the specified date & location
  result = api_instance.get_top_sectors(date, location, spending_type)
  p result
rescue OpenapiClient::ApiError => e
  puts "Exception when calling ReportsApi->get_top_sectors: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **date** | **Date**| The date for the requested data | 
 **location** | **String**| The location for which you wish to receive the top-sectors report. | 
 **spending_type** | **String**| Used to distinguish between gross spending (GS) &amp; average transaction value (ATV) | 

### Return type

**Array&lt;Array&gt;**

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

