# OpenapiClient::SubscribeApi

All URIs are relative to *https://stage.api.mastercard.com/golden-service*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_subscription**](SubscribeApi.md#get_subscription) | **GET** /subscriptions/{subscription_id} | Gets a specific subscription using a subscription Id passed as in the path
[**list_subscriptions**](SubscribeApi.md#list_subscriptions) | **GET** /subscriptions | gets all active subscriptions for a particular user. Returned list size can be limited using the limit parameter
[**subscribe**](SubscribeApi.md#subscribe) | **POST** /subscriptions | Allows the user to subscribe to a particular location and receive updates on e-commerce spending in their chosen area. The user can pay for the subscription on a daily basis. The user is charged for every report they receive until their subscription is cancelled
[**unsubscribe**](SubscribeApi.md#unsubscribe) | **DELETE** /subscriptions | Un-subscribes from a specified subcription
[**update_subscription**](SubscribeApi.md#update_subscription) | **PUT** /subscriptions | Updates an active subscription



## get_subscription

> SubscriptionResponse get_subscription(subscription_id)

Gets a specific subscription using a subscription Id passed as in the path

### Example

```ruby
# load the gem
require 'openapi_client'

api_instance = OpenapiClient::SubscribeApi.new
subscription_id = 'cb9fa3cc-8a06-39af-b605-934799914275' # String | Unique identifier of a particular subscription (UUID Version 4)

begin
  #Gets a specific subscription using a subscription Id passed as in the path
  result = api_instance.get_subscription(subscription_id)
  p result
rescue OpenapiClient::ApiError => e
  puts "Exception when calling SubscribeApi->get_subscription: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **subscription_id** | [**String**](.md)| Unique identifier of a particular subscription (UUID Version 4) | 

### Return type

[**SubscriptionResponse**](SubscriptionResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list_subscriptions

> Array&lt;ActiveSubscription&gt; list_subscriptions(opts)

gets all active subscriptions for a particular user. Returned list size can be limited using the limit parameter

### Example

```ruby
# load the gem
require 'openapi_client'

api_instance = OpenapiClient::SubscribeApi.new
opts = {
  limit: 5, # Integer | Can be used to limit the amount of results returned from a query (Pagination)
  offset: 5 # Integer | The number of items to offset the start of the list from (Pagination)
}

begin
  #gets all active subscriptions for a particular user. Returned list size can be limited using the limit parameter
  result = api_instance.list_subscriptions(opts)
  p result
rescue OpenapiClient::ApiError => e
  puts "Exception when calling SubscribeApi->list_subscriptions: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Can be used to limit the amount of results returned from a query (Pagination) | [optional] 
 **offset** | **Integer**| The number of items to offset the start of the list from (Pagination) | [optional] 

### Return type

[**Array&lt;ActiveSubscription&gt;**](ActiveSubscription.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## subscribe

> Array&lt;SubscriptionResponse&gt; subscribe(request_body)

Allows the user to subscribe to a particular location and receive updates on e-commerce spending in their chosen area. The user can pay for the subscription on a daily basis. The user is charged for every report they receive until their subscription is cancelled

### Example

```ruby
# load the gem
require 'openapi_client'

api_instance = OpenapiClient::SubscribeApi.new
request_body = {'key' => OpenapiClient::SubscriptionObject.new} # Hash<String, SubscriptionObject> | Request body required to create a particular subscription

begin
  #Allows the user to subscribe to a particular location and receive updates on e-commerce spending in their chosen area. The user can pay for the subscription on a daily basis. The user is charged for every report they receive until their subscription is cancelled
  result = api_instance.subscribe(request_body)
  p result
rescue OpenapiClient::ApiError => e
  puts "Exception when calling SubscribeApi->subscribe: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request_body** | [**Hash&lt;String, SubscriptionObject&gt;**](SubscriptionObject.md)| Request body required to create a particular subscription | 

### Return type

[**Array&lt;SubscriptionResponse&gt;**](SubscriptionResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## unsubscribe

> UnsubscribedResponse unsubscribe(subscription_id)

Un-subscribes from a specified subcription

### Example

```ruby
# load the gem
require 'openapi_client'

api_instance = OpenapiClient::SubscribeApi.new
subscription_id = 'cb9fa3cc-8a06-39af-b605-934799914275' # String | Unique identifier of a particular subscription (Version 4 UUID)

begin
  #Un-subscribes from a specified subcription
  result = api_instance.unsubscribe(subscription_id)
  p result
rescue OpenapiClient::ApiError => e
  puts "Exception when calling SubscribeApi->unsubscribe: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **subscription_id** | [**String**](.md)| Unique identifier of a particular subscription (Version 4 UUID) | 

### Return type

[**UnsubscribedResponse**](UnsubscribedResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_subscription

> SubscriptionResponse update_subscription(subscription_id, subscription_object)

Updates an active subscription

### Example

```ruby
# load the gem
require 'openapi_client'

api_instance = OpenapiClient::SubscribeApi.new
subscription_id = 'cb9fa3cc-8a06-39af-b605-934799914275' # String | Unique identifier of a particular subscription (UUID Version 4)
subscription_object = OpenapiClient::SubscriptionObject.new # SubscriptionObject | Request body required to update a particular subscription

begin
  #Updates an active subscription
  result = api_instance.update_subscription(subscription_id, subscription_object)
  p result
rescue OpenapiClient::ApiError => e
  puts "Exception when calling SubscribeApi->update_subscription: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **subscription_id** | [**String**](.md)| Unique identifier of a particular subscription (UUID Version 4) | 
 **subscription_object** | [**SubscriptionObject**](SubscriptionObject.md)| Request body required to update a particular subscription | 

### Return type

[**SubscriptionResponse**](SubscriptionResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

